@@ -2,7 +2,7 @@ package Net::DNS::RR::DS;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: DS.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+our $VERSION = (qw$Id: DS.pm 1957 2024-01-10 14:54:10Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -20,15 +20,11 @@ use Carp;
 use constant BABBLE => defined eval { require Digest::BubbleBabble };
 
 eval { require Digest::SHA };		## optional for simple Net::DNS RR
-eval { require Digest::GOST12 };
-eval { require Digest::GOST::CryptoPro };
 
 my %digest = (
 	'1' => scalar( eval { Digest::SHA->new(1) } ),
 	'2' => scalar( eval { Digest::SHA->new(256) } ),
-	'3' => scalar( eval { Digest::GOST::CryptoPro->new() } ),
 	'4' => scalar( eval { Digest::SHA->new(384) } ),
-	'5' => scalar( eval { Digest::GOST12->new() } ),
 	);
 
 
@@ -51,9 +47,13 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	$self->_annotation( $self->babble ) if BABBLE && $self->{algorithm};
-	my @param = @{$self}{qw(keytag algorithm digtype)};
-	my @rdata = ( @param, split /(\S{64})/, $self->digest || '-' );
+	my @rdata = @{$self}{qw(keytag algorithm digtype)};
+	if ( my $digest = $self->digest ) {
+		$self->_annotation( $self->babble ) if BABBLE;
+		push @rdata, split /(\S{64})/, $digest;
+	} else {
+		push @rdata, '""';
+	}
 	return @rdata;
 }
 
@@ -61,11 +61,11 @@ sub _format_rdata {			## format rdata portion of RR string.
 sub _parse_rdata {			## populate RR from rdata in argument list
 	my ( $self, @argument ) = @_;
 
-	my $keytag = shift @argument;	## avoid destruction by CDS algorithm(0)
-	$self->algorithm( shift @argument );
+	$self->keytag( shift @argument );
+	my $algorithm = shift @argument;
 	$self->digtype( shift @argument );
 	$self->digest(@argument);
-	$self->keytag($keytag);
+	$self->algorithm($algorithm);
 	return;
 }
 
@@ -129,19 +129,19 @@ sub create {
 	my ( $class, $keyrr, %args ) = @_;
 	my ($type) = reverse split '::', $class;
 
-	croak "Unable to create $type record for non-zone key" unless $keyrr->zone;
-	croak "Unable to create $type record for revoked key" if $keyrr->revoke;
 	croak "Unable to create $type record for invalid key" unless $keyrr->protocol == 3;
+	croak "Unable to create $type record for revoked key" if $keyrr->revoke;
+	croak "Unable to create $type record for non-zone key" unless $keyrr->zone;
 
 	my $self = Net::DNS::RR->new(
-		owner	  => $keyrr->owner,			# per definition, same as keyrr
-		type	  => $type,
-		class	  => $keyrr->class,
-		ttl	  => $keyrr->{ttl},
-		keytag	  => $keyrr->keytag,
+		owner	=> $keyrr->owner,			# per definition, same as keyrr
+		type	=> $type,
+		class	=> $keyrr->class,
+		ttl	=> $keyrr->{ttl},
+		digtype => 1,					# SHA1 by default
+		%args,
 		algorithm => $keyrr->algorithm,
-		digtype	  => 1,					# SHA1 by default
-		%args
+		keytag	  => $keyrr->keytag
 		);
 
 	my $hash = $digest{$self->digtype};
@@ -166,17 +166,14 @@ sub verify {
 
 {
 	my @digestbyname = (
-		'SHA-1'		    => 1,			# [RFC3658]
-		'SHA-256'	    => 2,			# [RFC4509]
-		'GOST-R-34.11-94'   => 3,			# [RFC5933]
-		'SHA-384'	    => 4,			# [RFC6605]
-		'GOST-R-34.11-2012' => 5,			# [RFC5933bis]
+		'SHA-1'		  => 1,				# [RFC3658]
+		'SHA-256'	  => 2,				# [RFC4509]
+		'GOST-R-34.11-94' => 3,				# [RFC5933]
+		'SHA-384'	  => 4,				# [RFC6605]
 		);
 
 	my @digestalias = (
 		'SHA'	 => 1,
-		'GOST94' => 3,
-		'GOST12' => 5,
 		);
 
 	my %digestbyval = reverse @digestbyname;
